===============================
Cotyledon
===============================

.. image:: https://travis-ci.org/sileht/cotyledon.png?branch=master
   :target: https://travis-ci.org/sileht/cotyledon

.. image:: https://img.shields.io/pypi/v/cotyledon.svg
   :target: https://pypi.python.org/pypi/cotyledon/
   :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/cotyledon.svg
   :target: https://pypi.python.org/pypi/cotyledon/
   :alt: Downloads



Cotyledon provides a framework for defining long-running services.

* Free software: Apache license
* Documentation: http://cotyledon.readthedocs.org/
* Source: https://github.com/sileht/cotyledon
* Bugs: https://github.com/sileht/cotyledon/issues
